# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sentence_transformer.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1asentence_transformer.proto\x12 cognica.rpc.sentence_transformer\"$\n\x06Tensor\x12\x0c\n\x04\x64ims\x18\x01 \x01(\x05\x12\x0c\n\x04\x64\x61ta\x18\x02 \x03(\x02\"\"\n\x0bProfileInfo\x12\x13\n\x0b\x64uration_us\x18\x01 \x01(\x04\"?\n\x16SentenceEncoderRequest\x12\x12\n\nmodel_name\x18\x01 \x01(\t\x12\x11\n\tsentences\x18\x02 \x03(\t\"\xe7\x01\n\x17SentenceEncoderResponse\x12<\n\x06status\x18\x01 \x01(\x0e\x32,.cognica.rpc.sentence_transformer.StatusType\x12\x12\n\nmodel_name\x18\x02 \x01(\t\x12\x39\n\x07tensors\x18\x03 \x03(\x0b\x32(.cognica.rpc.sentence_transformer.Tensor\x12?\n\x08profiles\x18\x04 \x03(\x0b\x32-.cognica.rpc.sentence_transformer.ProfileInfo\"4\n\x0cSentencePair\x12\x11\n\tsentence1\x18\x01 \x01(\t\x12\x11\n\tsentence2\x18\x02 \x01(\t\"l\n\x13\x43rossEncoderRequest\x12\x12\n\nmodel_name\x18\x01 \x01(\t\x12\x41\n\tsentences\x18\x02 \x03(\x0b\x32..cognica.rpc.sentence_transformer.SentencePair\"\xb9\x01\n\x14\x43rossEncoderResponse\x12<\n\x06status\x18\x01 \x01(\x0e\x32,.cognica.rpc.sentence_transformer.StatusType\x12\x12\n\nmodel_name\x18\x02 \x01(\t\x12\x0e\n\x06scores\x18\x03 \x03(\x02\x12?\n\x08profiles\x18\x04 \x03(\x0b\x32-.cognica.rpc.sentence_transformer.ProfileInfo\"\xb0\x01\n\x12\x43LIPEncoderRequest\x12\x12\n\nmodel_name\x18\x01 \x01(\t\x12P\n\x06\x66ormat\x18\x02 \x01(\x0e\x32@.cognica.rpc.sentence_transformer.CLIPEncoderRequest.InputFormat\x12\x0e\n\x06inputs\x18\x03 \x03(\x0c\"$\n\x0bInputFormat\x12\t\n\x05kText\x10\x00\x12\n\n\x06kImage\x10\x01\"\xe3\x01\n\x13\x43LIPEncoderResponse\x12<\n\x06status\x18\x01 \x01(\x0e\x32,.cognica.rpc.sentence_transformer.StatusType\x12\x12\n\nmodel_name\x18\x02 \x01(\t\x12\x39\n\x07tensors\x18\x03 \x03(\x0b\x32(.cognica.rpc.sentence_transformer.Tensor\x12?\n\x08profiles\x18\x04 \x03(\x0b\x32-.cognica.rpc.sentence_transformer.ProfileInfo\"Z\n\x10QAEncoderRequest\x12\x12\n\nmodel_name\x18\x01 \x01(\t\x12\x11\n\tquestions\x18\x02 \x03(\t\x12\x10\n\x08\x63ontexts\x18\x03 \x03(\t\x12\r\n\x05top_k\x18\x04 \x01(\x05\"\xa6\x03\n\x11QAEncoderResponse\x12<\n\x06status\x18\x01 \x01(\x0e\x32,.cognica.rpc.sentence_transformer.StatusType\x12\x12\n\nmodel_name\x18\x02 \x01(\t\x12R\n\x07\x61nswers\x18\x03 \x03(\x0b\x32\x41.cognica.rpc.sentence_transformer.QAEncoderResponse.CandidateList\x12?\n\x08profiles\x18\x04 \x03(\x0b\x32-.cognica.rpc.sentence_transformer.ProfileInfo\x1a\x46\n\tCandidate\x12\r\n\x05score\x18\x01 \x01(\x02\x12\r\n\x05\x62\x65gin\x18\x02 \x01(\x05\x12\x0b\n\x03\x65nd\x18\x03 \x01(\x05\x12\x0e\n\x06\x61nswer\x18\x04 \x01(\t\x1a\x62\n\rCandidateList\x12Q\n\ncandidates\x18\x01 \x03(\x0b\x32=.cognica.rpc.sentence_transformer.QAEncoderResponse.Candidate*3\n\nStatusType\x12\x07\n\x03kOK\x10\x00\x12\r\n\tkNotFound\x10\x01\x12\r\n\tkInternal\x10\n2\x9d\x01\n\x1aSentenceTransformerService\x12\x7f\n\x06\x65ncode\x12\x38.cognica.rpc.sentence_transformer.SentenceEncoderRequest\x1a\x39.cognica.rpc.sentence_transformer.SentenceEncoderResponse\"\x00\x32\x91\x01\n\x13\x43rossEncoderService\x12z\n\x07predict\x12\x35.cognica.rpc.sentence_transformer.CrossEncoderRequest\x1a\x36.cognica.rpc.sentence_transformer.CrossEncoderResponse\"\x00\x32\x8d\x01\n\x12\x43LIPEncoderService\x12w\n\x06\x65ncode\x12\x34.cognica.rpc.sentence_transformer.CLIPEncoderRequest\x1a\x35.cognica.rpc.sentence_transformer.CLIPEncoderResponse\"\x00\x32\x88\x01\n\x10QAEncoderService\x12t\n\x07predict\x12\x32.cognica.rpc.sentence_transformer.QAEncoderRequest\x1a\x33.cognica.rpc.sentence_transformer.QAEncoderResponse\"\x00\x42\x03\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentence_transformer_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\370\001\001'
  _STATUSTYPE._serialized_start=1715
  _STATUSTYPE._serialized_end=1766
  _TENSOR._serialized_start=64
  _TENSOR._serialized_end=100
  _PROFILEINFO._serialized_start=102
  _PROFILEINFO._serialized_end=136
  _SENTENCEENCODERREQUEST._serialized_start=138
  _SENTENCEENCODERREQUEST._serialized_end=201
  _SENTENCEENCODERRESPONSE._serialized_start=204
  _SENTENCEENCODERRESPONSE._serialized_end=435
  _SENTENCEPAIR._serialized_start=437
  _SENTENCEPAIR._serialized_end=489
  _CROSSENCODERREQUEST._serialized_start=491
  _CROSSENCODERREQUEST._serialized_end=599
  _CROSSENCODERRESPONSE._serialized_start=602
  _CROSSENCODERRESPONSE._serialized_end=787
  _CLIPENCODERREQUEST._serialized_start=790
  _CLIPENCODERREQUEST._serialized_end=966
  _CLIPENCODERREQUEST_INPUTFORMAT._serialized_start=930
  _CLIPENCODERREQUEST_INPUTFORMAT._serialized_end=966
  _CLIPENCODERRESPONSE._serialized_start=969
  _CLIPENCODERRESPONSE._serialized_end=1196
  _QAENCODERREQUEST._serialized_start=1198
  _QAENCODERREQUEST._serialized_end=1288
  _QAENCODERRESPONSE._serialized_start=1291
  _QAENCODERRESPONSE._serialized_end=1713
  _QAENCODERRESPONSE_CANDIDATE._serialized_start=1543
  _QAENCODERRESPONSE_CANDIDATE._serialized_end=1613
  _QAENCODERRESPONSE_CANDIDATELIST._serialized_start=1615
  _QAENCODERRESPONSE_CANDIDATELIST._serialized_end=1713
  _SENTENCETRANSFORMERSERVICE._serialized_start=1769
  _SENTENCETRANSFORMERSERVICE._serialized_end=1926
  _CROSSENCODERSERVICE._serialized_start=1929
  _CROSSENCODERSERVICE._serialized_end=2074
  _CLIPENCODERSERVICE._serialized_start=2077
  _CLIPENCODERSERVICE._serialized_end=2218
  _QAENCODERSERVICE._serialized_start=2221
  _QAENCODERSERVICE._serialized_end=2357
# @@protoc_insertion_point(module_scope)
