# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: document.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0e\x64ocument.proto\x12\x17\x63ognica.rpc.db.document\"\xdb\x01\n\x05Value\x12\x0e\n\x04null\x18\x01 \x01(\x08H\x00\x12\x0e\n\x04\x62ool\x18\x02 \x01(\x08H\x00\x12\x0f\n\x05int64\x18\x03 \x01(\x03H\x00\x12\x10\n\x06uint64\x18\x04 \x01(\x04H\x00\x12\x10\n\x06\x64ouble\x18\x05 \x01(\x01H\x00\x12\x10\n\x06string\x18\x06 \x01(\tH\x00\x12/\n\x05\x61rray\x18\x07 \x01(\x0b\x32\x1e.cognica.rpc.db.document.ArrayH\x00\x12\x31\n\x06object\x18\x08 \x01(\x0b\x32\x1f.cognica.rpc.db.document.ObjectH\x00\x42\x07\n\x05value\"6\n\x05\x41rray\x12-\n\x05value\x18\x01 \x03(\x0b\x32\x1e.cognica.rpc.db.document.Value\"\x91\x01\n\x06Object\x12\x39\n\x05value\x18\x01 \x03(\x0b\x32*.cognica.rpc.db.document.Object.ValueEntry\x1aL\n\nValueEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12-\n\x05value\x18\x02 \x01(\x0b\x32\x1e.cognica.rpc.db.document.Value:\x02\x38\x01\"U\n\x08\x44ocument\x12\x31\n\x06object\x18\x01 \x01(\x0b\x32\x1f.cognica.rpc.db.document.ObjectH\x00\x12\x0e\n\x04json\x18\x02 \x01(\tH\x00\x42\x06\n\x04typeB\x03\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'document_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\370\001\001'
  _OBJECT_VALUEENTRY._options = None
  _OBJECT_VALUEENTRY._serialized_options = b'8\001'
  _VALUE._serialized_start=44
  _VALUE._serialized_end=263
  _ARRAY._serialized_start=265
  _ARRAY._serialized_end=319
  _OBJECT._serialized_start=322
  _OBJECT._serialized_end=467
  _OBJECT_VALUEENTRY._serialized_start=391
  _OBJECT_VALUEENTRY._serialized_end=467
  _DOCUMENT._serialized_start=469
  _DOCUMENT._serialized_end=554
# @@protoc_insertion_point(module_scope)
