# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: key_value_db.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12key_value_db.proto\x12\x11\x63ognica.rpc.db.kv\"\"\n\x0bProfileInfo\x12\x13\n\x0b\x64uration_us\x18\x01 \x01(\x04\"{\n\x08Response\x12-\n\x06status\x18\x01 \x01(\x0e\x32\x1d.cognica.rpc.db.kv.StatusType\x12\x0f\n\x07message\x18\x02 \x01(\t\x12/\n\x07profile\x18\x03 \x01(\x0b\x32\x1e.cognica.rpc.db.kv.ProfileInfo\"g\n\nPutRequest\x12\x15\n\rkeyspace_name\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\x0c\x12\r\n\x05value\x18\x03 \x01(\x0c\x12\x0b\n\x03ttl\x18\x04 \x01(\x03\x12\x19\n\x11\x63reate_if_missing\x18\x05 \x01(\x08\"<\n\x0bPutResponse\x12-\n\x08response\x18\x01 \x01(\x0b\x32\x1b.cognica.rpc.db.kv.Response\"3\n\rRemoveRequest\x12\x15\n\rkeyspace_name\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\x0c\"?\n\x0eRemoveResponse\x12-\n\x08response\x18\x01 \x01(\x0b\x32\x1b.cognica.rpc.db.kv.Response\"0\n\nGetRequest\x12\x15\n\rkeyspace_name\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\x0c\"K\n\x0bGetResponse\x12-\n\x08response\x18\x01 \x01(\x0b\x32\x1b.cognica.rpc.db.kv.Response\x12\r\n\x05value\x18\x02 \x01(\x0c\"6\n\x0fMultiGetRequest\x12\x15\n\rkeyspace_name\x18\x01 \x01(\t\x12\x0c\n\x04keys\x18\x02 \x03(\x0c\"R\n\x10MultiGetResponse\x12.\n\tresponses\x18\x01 \x03(\x0b\x32\x1b.cognica.rpc.db.kv.Response\x12\x0e\n\x06values\x18\x02 \x03(\x0c\"q\n\x11\x42\x61tchedPutRequest\x12\x15\n\rkeyspace_name\x18\x01 \x01(\t\x12\x0c\n\x04keys\x18\x02 \x03(\x0c\x12\x0e\n\x06values\x18\x03 \x03(\x0c\x12\x0c\n\x04ttls\x18\x04 \x03(\x03\x12\x19\n\x11\x63reate_if_missing\x18\x05 \x01(\x08\"D\n\x12\x42\x61tchedPutResponse\x12.\n\tresponses\x18\x01 \x03(\x0b\x32\x1b.cognica.rpc.db.kv.Response\";\n\x14\x42\x61tchedRemoveRequest\x12\x15\n\rkeyspace_name\x18\x01 \x01(\t\x12\x0c\n\x04keys\x18\x02 \x03(\x0c\"G\n\x15\x42\x61tchedRemoveResponse\x12.\n\tresponses\x18\x01 \x03(\x0b\x32\x1b.cognica.rpc.db.kv.Response\"8\n\x11\x42\x61tchedGetRequest\x12\x15\n\rkeyspace_name\x18\x01 \x01(\t\x12\x0c\n\x04keys\x18\x02 \x03(\x0c\"T\n\x12\x42\x61tchedGetResponse\x12.\n\tresponses\x18\x01 \x03(\x0b\x32\x1b.cognica.rpc.db.kv.Response\x12\x0e\n\x06values\x18\x02 \x03(\x0c\".\n\x15\x43reateKeyspaceRequest\x12\x15\n\rkeyspace_name\x18\x01 \x01(\t\"G\n\x16\x43reateKeyspaceResponse\x12-\n\x08response\x18\x01 \x01(\x0b\x32\x1b.cognica.rpc.db.kv.Response\",\n\x13\x44ropKeyspaceRequest\x12\x15\n\rkeyspace_name\x18\x01 \x01(\t\"E\n\x14\x44ropKeyspaceResponse\x12-\n\x08response\x18\x01 \x01(\x0b\x32\x1b.cognica.rpc.db.kv.Response\"0\n\x17TruncateKeyspaceRequest\x12\x15\n\rkeyspace_name\x18\x01 \x01(\t\"I\n\x18TruncateKeyspaceResponse\x12-\n\x08response\x18\x01 \x01(\x0b\x32\x1b.cognica.rpc.db.kv.Response\"\x16\n\x14ListKeyspacesRequest\"^\n\x15ListKeyspacesResponse\x12-\n\x08response\x18\x01 \x01(\x0b\x32\x1b.cognica.rpc.db.kv.Response\x12\x16\n\x0ekeyspace_names\x18\x02 \x03(\t*3\n\nStatusType\x12\x07\n\x03kOK\x10\x00\x12\r\n\tkNotFound\x10\x01\x12\r\n\tkInternal\x10\n2\xe4\x04\n\x11KeyValueDBService\x12\x46\n\x03put\x12\x1d.cognica.rpc.db.kv.PutRequest\x1a\x1e.cognica.rpc.db.kv.PutResponse\"\x00\x12O\n\x06remove\x12 .cognica.rpc.db.kv.RemoveRequest\x1a!.cognica.rpc.db.kv.RemoveResponse\"\x00\x12\x46\n\x03get\x12\x1d.cognica.rpc.db.kv.GetRequest\x1a\x1e.cognica.rpc.db.kv.GetResponse\"\x00\x12Q\n\x04mget\x12\".cognica.rpc.db.kv.MultiGetRequest\x1a#.cognica.rpc.db.kv.MultiGetResponse\"\x00\x12Z\n\tput_batch\x12$.cognica.rpc.db.kv.BatchedPutRequest\x1a%.cognica.rpc.db.kv.BatchedPutResponse\"\x00\x12\x63\n\x0cremove_batch\x12\'.cognica.rpc.db.kv.BatchedRemoveRequest\x1a(.cognica.rpc.db.kv.BatchedRemoveResponse\"\x00\x12Z\n\tget_batch\x12$.cognica.rpc.db.kv.BatchedGetRequest\x1a%.cognica.rpc.db.kv.BatchedGetResponse\"\x00\x32\xbd\x03\n\x16KeyspaceManagerService\x12h\n\x0f\x63reate_keyspace\x12(.cognica.rpc.db.kv.CreateKeyspaceRequest\x1a).cognica.rpc.db.kv.CreateKeyspaceResponse\"\x00\x12\x62\n\rdrop_keyspace\x12&.cognica.rpc.db.kv.DropKeyspaceRequest\x1a\'.cognica.rpc.db.kv.DropKeyspaceResponse\"\x00\x12n\n\x11truncate_keyspace\x12*.cognica.rpc.db.kv.TruncateKeyspaceRequest\x1a+.cognica.rpc.db.kv.TruncateKeyspaceResponse\"\x00\x12\x65\n\x0elist_keyspaces\x12\'.cognica.rpc.db.kv.ListKeyspacesRequest\x1a(.cognica.rpc.db.kv.ListKeyspacesResponse\"\x00\x42\x03\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'key_value_db_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\370\001\001'
  _STATUSTYPE._serialized_start=1700
  _STATUSTYPE._serialized_end=1751
  _PROFILEINFO._serialized_start=41
  _PROFILEINFO._serialized_end=75
  _RESPONSE._serialized_start=77
  _RESPONSE._serialized_end=200
  _PUTREQUEST._serialized_start=202
  _PUTREQUEST._serialized_end=305
  _PUTRESPONSE._serialized_start=307
  _PUTRESPONSE._serialized_end=367
  _REMOVEREQUEST._serialized_start=369
  _REMOVEREQUEST._serialized_end=420
  _REMOVERESPONSE._serialized_start=422
  _REMOVERESPONSE._serialized_end=485
  _GETREQUEST._serialized_start=487
  _GETREQUEST._serialized_end=535
  _GETRESPONSE._serialized_start=537
  _GETRESPONSE._serialized_end=612
  _MULTIGETREQUEST._serialized_start=614
  _MULTIGETREQUEST._serialized_end=668
  _MULTIGETRESPONSE._serialized_start=670
  _MULTIGETRESPONSE._serialized_end=752
  _BATCHEDPUTREQUEST._serialized_start=754
  _BATCHEDPUTREQUEST._serialized_end=867
  _BATCHEDPUTRESPONSE._serialized_start=869
  _BATCHEDPUTRESPONSE._serialized_end=937
  _BATCHEDREMOVEREQUEST._serialized_start=939
  _BATCHEDREMOVEREQUEST._serialized_end=998
  _BATCHEDREMOVERESPONSE._serialized_start=1000
  _BATCHEDREMOVERESPONSE._serialized_end=1071
  _BATCHEDGETREQUEST._serialized_start=1073
  _BATCHEDGETREQUEST._serialized_end=1129
  _BATCHEDGETRESPONSE._serialized_start=1131
  _BATCHEDGETRESPONSE._serialized_end=1215
  _CREATEKEYSPACEREQUEST._serialized_start=1217
  _CREATEKEYSPACEREQUEST._serialized_end=1263
  _CREATEKEYSPACERESPONSE._serialized_start=1265
  _CREATEKEYSPACERESPONSE._serialized_end=1336
  _DROPKEYSPACEREQUEST._serialized_start=1338
  _DROPKEYSPACEREQUEST._serialized_end=1382
  _DROPKEYSPACERESPONSE._serialized_start=1384
  _DROPKEYSPACERESPONSE._serialized_end=1453
  _TRUNCATEKEYSPACEREQUEST._serialized_start=1455
  _TRUNCATEKEYSPACEREQUEST._serialized_end=1503
  _TRUNCATEKEYSPACERESPONSE._serialized_start=1505
  _TRUNCATEKEYSPACERESPONSE._serialized_end=1578
  _LISTKEYSPACESREQUEST._serialized_start=1580
  _LISTKEYSPACESREQUEST._serialized_end=1602
  _LISTKEYSPACESRESPONSE._serialized_start=1604
  _LISTKEYSPACESRESPONSE._serialized_end=1698
  _KEYVALUEDBSERVICE._serialized_start=1754
  _KEYVALUEDBSERVICE._serialized_end=2366
  _KEYSPACEMANAGERSERVICE._serialized_start=2369
  _KEYSPACEMANAGERSERVICE._serialized_end=2814
# @@protoc_insertion_point(module_scope)
