# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fts_analysis_pipeline.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x66ts_analysis_pipeline.proto\x12\x12\x63ognica.rpc.db.fts\"\"\n\x0bProfileInfo\x12\x13\n\x0b\x64uration_us\x18\x01 \x01(\x04\"k\n\x18PipelineExecutionRequest\x12\x17\n\x0f\x63ollection_name\x18\x01 \x01(\t\x12\x12\n\nindex_name\x18\x02 \x01(\t\x12\x13\n\x0b\x66ield_names\x18\x03 \x03(\t\x12\r\n\x05query\x18\x04 \x01(\t\"m\n\x19PipelineExecutionResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x0e\n\x06result\x18\x02 \x01(\t\x12\x30\n\x07profile\x18\x03 \x01(\x0b\x32\x1f.cognica.rpc.db.fts.ProfileInfo\"Y\n\x1d\x41\x64hocPipelineExecutionRequest\x12\x14\n\x0cpipeline_def\x18\x01 \x01(\t\x12\x13\n\x0b\x66ield_names\x18\x02 \x03(\t\x12\r\n\x05query\x18\x03 \x01(\t\"r\n\x1e\x41\x64hocPipelineExecutionResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x0e\n\x06result\x18\x02 \x01(\t\x12\x30\n\x07profile\x18\x03 \x01(\x0b\x32\x1f.cognica.rpc.db.fts.ProfileInfo2\x80\x02\n\x1a\x46TSAnalysisPipelineService\x12h\n\x07\x65xecute\x12,.cognica.rpc.db.fts.PipelineExecutionRequest\x1a-.cognica.rpc.db.fts.PipelineExecutionResponse\"\x00\x12x\n\rexecute_adhoc\x12\x31.cognica.rpc.db.fts.AdhocPipelineExecutionRequest\x1a\x32.cognica.rpc.db.fts.AdhocPipelineExecutionResponse\"\x00\x42\x03\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fts_analysis_pipeline_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\370\001\001'
  _PROFILEINFO._serialized_start=51
  _PROFILEINFO._serialized_end=85
  _PIPELINEEXECUTIONREQUEST._serialized_start=87
  _PIPELINEEXECUTIONREQUEST._serialized_end=194
  _PIPELINEEXECUTIONRESPONSE._serialized_start=196
  _PIPELINEEXECUTIONRESPONSE._serialized_end=305
  _ADHOCPIPELINEEXECUTIONREQUEST._serialized_start=307
  _ADHOCPIPELINEEXECUTIONREQUEST._serialized_end=396
  _ADHOCPIPELINEEXECUTIONRESPONSE._serialized_start=398
  _ADHOCPIPELINEEXECUTIONRESPONSE._serialized_end=512
  _FTSANALYSISPIPELINESERVICE._serialized_start=515
  _FTSANALYSISPIPELINESERVICE._serialized_end=771
# @@protoc_insertion_point(module_scope)
